#
# spec file for package python-peppercorn
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2017 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-peppercorn
Version:        0.6
Release:        5.1
Summary:        Pyramid exceptions logger
License:        BSD-4-Clause AND ZPL-2.1 AND MIT
URL:            https://docs.pylonsproject.org/projects/peppercorn/en/latest/
# SourceRepostory: https://github.com/Pylons/peppercorn
Source:         https://files.pythonhosted.org/packages/source/p/peppercorn/peppercorn-%{version}.tar.gz
BuildRequires:  %{python_module legacy-cgi if %python-base >= 3.13}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pylons-sphinx-themes}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# Documentation requirement
BuildRequires:  python3-Sphinx
%if %{python_version_nodots} >= 313
Requires:       python-legacy-cgi
%endif
BuildArch:      noarch
%python_subpackages

%description
A library for converting a token stream into a data structure comprised of
sequences, mappings, and scalars, developed primarily for converting HTTP form
POST data into a richer data structure.

%package -n %{name}-doc
Summary:        Documentation for Pyramid exceptions logger

%description -n %{name}-doc
This package contains documentation for %{name}.

%prep
%setup -q -n peppercorn-%{version}

%build
%pyproject_wheel
PYTHONPATH=":x" sphinx-build -b html docs/ build/sphinx/html/
rm -r build/sphinx/html/{.buildinfo,.doctrees}

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pyunittest -v

%files %{python_files}
%license LICENSE.txt
%doc CHANGES.rst CONTRIBUTORS.txt COPYRIGHT.txt README.rst contributing.md
%{python_sitelib}/peppercorn-%{version}.dist-info
%{python_sitelib}/peppercorn

%files -n %{name}-doc
%doc build/sphinx/html

%changelog
* Thu Nov 21 2024 Dirk Müller <dmueller@suse.com>
- require legacy-cgi for python 3.13 support
* Thu May 11 2023 Ben Greiner <code@bnavigator.de>
- Replace build_sphinx setuptools hook with direct sphinx-build
  call -- fixes boo#1211051
* Mon May  4 2020 Paolo Stivanin <info@paolostivanin.com>
- Remove nose and use unittest instead
* Mon Oct 14 2019 Matej Cepl <mcepl@suse.com>
- Replace %%fdupes -s with plain %%fdupes; hardlinks are better.
* Tue May 21 2019 pgajdos@suse.com
- version update to 0.6
  * Add support for Python 3.4, 3.5, 3.6 and 3.7.
  * Drop support for Python 2.6, 3.2 and 3.3.
  * Add contributing.md and update docs.
- deleted patches
  - peppercorn-0.5-fix-pylons-theme.patch (upstreamed)
* Tue Dec 18 2018 Jan Engelhardt <jengelh@inai.de>
- Grammar fixes for the description. Remove an excessive Requires.
* Thu Jun 21 2018 hpj@urpla.net
- add patch peppercorn-0.5-fix-pylons-theme.patch to build docs properly
* Wed Oct  4 2017 bruno@ioda-net.ch
- Build doc with python3 only
* Tue Sep 19 2017 bruno@ioda-net.ch
- Migrate to singlespec with spec-cleanup
* Fri Feb  6 2015 hpj@urpla.net
- version 0.5
  - Switch to an iterative parser rather than a recursive parser to avoid DoS
    attacks.
  - Add the ignore operation. The subsequent data elements in the stream will
    be ignored until the corresponding __end__ marker. This feature is useful
    for form elements designed for client-side scripting, such as a “select all”
    checkbox in the middle of a list of other kinds of fields.
  - Add support for Python 3.3.
  - Drop support for Python 2.5 / Jython.
* Mon Aug  5 2013 hpj@urpla.net
- version 0.4: initial build
